@@ -5,7 +5,7 @@ import requests
 import re
 
 NW = re.compile(r'\W')
-
+UA = 'Mozilla/5.0 (Windows; U; Windows NT 6.1; ) AppleWebKit/534.12 (KHTML, like Gecko) Maxthon/3.0 Safari/534.12'
 def GetLinks(url, proxy=None,domain=None, text=False):
     doc = None
     basehost = None
@@ -13,6 +13,7 @@ def GetLinks(url, proxy=None,domain=None, text=False):
         basehost = up.urlsplit(url).hostname
         domain = basehost
         sess = requests.Session()
+        sess.headers['User-Agent'] = UA
         if proxy != None:
             sess.proxies['http'] = sess.proxies['https'] = proxy
         raw = sess.get(url).content
